@@ -5,7 +5,7 @@
 #'
 #' @param x object of class \code{fairness_object}
 #' @param grid_points numeric, grid for cutoffs to test. Number of points between 0 and 1 spread evenly
-#' @param fairness_metrics character, name of metric or vector of multiple metrics names
+#' @param fairness_metrics character, name of parity_loss metric or vector of multiple metrics names. Full names can be found in \code{fairness_check} documentation.
 #'
 #' @return \code{all_cutoffs} object, \code{data.frame} containing information about label, metric and parity_loss at particular cutoff
 #' @export
@@ -32,15 +32,13 @@
 #'                           privileged = "male")
 #'
 #'
-#' ac <- all_cutoffs(fobject,
-#'                   fairness_metrics = c("TPR",
-#'                                        "FPR"))
+#' ac <- all_cutoffs(fobject)
 #' plot(ac)
 #'
 
 all_cutoffs <- function(x,
                         grid_points = 101,
-                        fairness_metrics = fairness_check_metrics()){
+                        fairness_metrics = c('ACC', 'TPR', 'PPV', 'FPR', 'STP')){
 
   stopifnot(class(x) == "fairness_object")
 
@@ -52,6 +50,7 @@ all_cutoffs <- function(x,
 
 
   explainers <- x$explainers
+  n_exp      <- length(explainers)
   cutoffs    <- seq(0,1, length.out =  grid_points)
   protected  <- x$protected
   privileged <- x$privileged
@@ -61,6 +60,7 @@ all_cutoffs <- function(x,
 
   # custom cutoffs will give messages (0 in matrices, NA in metrics)  numerous times,
   # so for code below they will be suppressed
+  parity_loss_metric_data       <- matrix(nrow = n_exp, ncol = 12)
 
   suppressMessages(
   for (i in seq_along(explainers)){
@@ -77,15 +77,13 @@ all_cutoffs <- function(x,
                                        cutoff = custom_cutoff_vec)
 
       # like in create fobject
-      gmm             <- calculate_group_fairness_metrics(group_matrices)
-      gmm_scaled      <- abs(apply(gmm, 2 , function(x) x  - gmm[,privileged]))
-      gmm_loss        <- rowSums(gmm_scaled)
+      gmm            <- calculate_group_fairness_metrics(group_matrices)
+      parity_loss    <- calculate_parity_loss(gmm, privileged)
+      parity_loss <- parity_loss[names(parity_loss) %in% fairness_metrics]
 
-      gmm_loss_unique <- gmm_loss[names(gmm_loss) %in% fairness_metrics]
-
-      to_add <- data.frame(parity_loss = as.numeric(gmm_loss_unique),
-                           metric      = names(gmm_loss_unique),
-                           cutoff      = rep(custom_cutoff, length(gmm_loss_unique)),
+      to_add <- data.frame(parity_loss = as.numeric(parity_loss),
+                           metric      = names(parity_loss),
+                           cutoff      = rep(custom_cutoff, length(parity_loss)),
                            label       = x$label[i])
 
       cutoff_data <- rbind(cutoff_data , to_add)
